@@ -26,7 +26,7 @@
 #'  - \url{https://www.isric.org/sites/default/files/GlobalSoilMap_specifications_december_2015_2.pdf}
 #' 
 #' @references Poggio, L., de Sousa, L. M., Batjes, N. H., Heuvelink, G. B. M., Kempen, B., Ribeiro, E., and Rossiter, D.: SoilGrids 2.0: producing soil information for the globe with quantified spatial uncertainty, SOIL, 7, 217-240, 2021. \doi{https://doi.org/10.5194/soil-7-217-2021}
-#'
+#' @importFrom utils packageVersion
 #' @param x A \code{data.frame} containing 3 columns referring to site ID, latitude and longitude.
 #' @param loc.names Optional: Column names referring to site ID, latitude and longitude. Default: \code{c("id","lat","lon")}
 #' @param verbose Print messages? Default: `FALSE`
@@ -60,8 +60,9 @@ fetchSoilGrids <- function(x,
   
   if (inherits(locations, 'sf') || inherits(locations, 'Spatial')) {
     if (requireNamespace("sf")) {
-      if (inherits(locations, 'Spatial')) {
-        # convert sp -> sf
+      if (inherits(locations, 'Spatial') ||
+          inherits(locations, 'SpatVector')) {
+        # convert sp -> sf & terra -> sf
         locations <- sf::st_as_sf(locations)
       }
       
@@ -124,6 +125,17 @@ fetchSoilGrids <- function(x,
     r.content <- httr::content(response, as = "text", encoding = "UTF-8")
     jres <- jsonlite::fromJSON(r.content)
     
+    # add handling for messages from api about erroneous input
+    if (!is.null(jres$detail)) {
+      if (!is.null(jres$detail$msg)) {
+        if (!is.null(jres$detail$loc) && length(jres$detail$loc) > 0)
+          message("Check ", 
+                  paste0(jres$detail$loc[[1]], collapse = " "), 
+                  " (", loc.names[1], ":", locations[[loc.names[1]]][i], "); ",
+                  jres$detail$msg)
+      }
+    }
+    
     # create new horizon data, merge in each property using standard depth labels
     depth.intervals <-  c("0-5", "5-15", "15-30", "30-60", "60-100", "100-200")
     hz.data <- data.frame(id = id, latitude = lat, longitude = lon, label = depth.intervals, stringsAsFactors = FALSE)
@@ -148,7 +160,7 @@ fetchSoilGrids <- function(x,
   }
   
   # combine horizon data together
-  spc <- do.call('rbind', res)
+  spc <- data.table::rbindlist(res, fill = TRUE)
   
   # calculate top and bottom depths from label
   labelsplit <- strsplit(as.character(spc$label), split = "-")
@@ -161,9 +173,16 @@ fetchSoilGrids <- function(x,
   
   # move location information to site
   aqp::site(spc) <- ~ longitude + latitude
-  aqp::coordinates(spc) <- ~ longitude + latitude
-  aqp::proj4string(spc) <- "EPSG:4326"
- 
+  
+  # if (utils::packageVersion("aqp") >= 2.0) {
+  #   aqp::initSpatial(spc, crs = "OGC:CRS84") <- ~ longitude + latitude
+  # } else {
+  suppressWarnings({
+    aqp::coordinates(spc) <- ~ longitude + latitude
+    aqp::proj4string(spc) <- "EPSG:4326"
+  })  
+  # }
+  
   # merge the rest of the sf object into the site table 
   if (spatial_input) {
     site(spc) <- cbind(id = 1:nrow(x), sf::st_drop_geometry(x))
@@ -183,13 +202,23 @@ fetchSoilGrids <- function(x,
   
   out[["values"]] <- cbind(sgvalues, uncertainty)
   
-  # fix names and labels for downstream
-  out <- out[,colnames(out)[grep("range", colnames(out), invert = TRUE)]]
-  out <- data.frame(label = gsub("cm", "", out$label), values = out$values)
-  colnames(out) <- gsub("\\.Q0\\.", "Q", colnames(out))
-  colnames(out) <- gsub("Q5", "Q50", colnames(out))
-  colnames(out) <- gsub("values", x, colnames(out))
-  colnames(out) <- gsub("\\.", "", colnames(out))
-  
+  if (nrow(out[["values"]]) == 0) {
+    out <- data.frame(range = NA, 
+                      label = c("0-5", "5-15", "15-30", 
+                                "30-60", "60-100", "100-200"), 
+                      values = data.frame(
+                          Q0.05 = rep(NA_real_, 6), Q0.5 = rep(NA_real_, 6), Q0.95 = rep(NA_real_, 6),
+                          mean = rep(NA_real_, 6), uncertainty = rep(NA_real_, 6)
+                       ))
+  }
+  # } else {
+    # fix names and labels for downstream
+    out <- out[,colnames(out)[grep("range", colnames(out), invert = TRUE)]]
+    out <- cbind(label = gsub("cm", "", out$label), values = out$values)
+    colnames(out) <- gsub("\\.Q0\\.", "Q", colnames(out))
+    colnames(out) <- gsub("Q5", "Q50", colnames(out))
+    colnames(out) <- gsub("values", x, colnames(out))
+    colnames(out) <- gsub("\\.", "", colnames(out))
+  # }
   return(out)
 }
