@@ -23,12 +23,13 @@ test_that("fetchSoilGrids() works as expected", {
   expect_equal(length(res), 2)
   expect_equal(nrow(res),   2*6)
 
-  expect_equal(ncol(site(res)), 1)
   expect_equal(ncol(horizons(res)), 2*25)
 
   # data conversion works
   expect_equal(res$claymean[1], 18.7)
-
+  
+  skip_if(as.logical(Sys.getenv("R_SOILDB_SKIP_LONG_EXAMPLES", unset = TRUE)))
+  
   # default names kick in
   expect_silent( {res <- fetchSoilGrids(your.points, loc.names = NULL)} )
 
